@@ -1,7 +1,7 @@
 ### Classical Runge-Kutta-fixed-step-integration
 ### R-Implementation by Th. Petzoldt,
 ### using some code from Woodrow Setzer
-rk4 <- function(y, times, func, parms) {
+rk4 <- function(y, times, func, parms, ...) {
     if (!is.numeric(y)) stop("`y' must be numeric")
     if (!is.numeric(times)) stop("`times' must be numeric")
     if (!is.function(func)) stop("`func' must be a function")
