@@ -6,14 +6,13 @@ extern SEXP odesolve_deriv_func;
 extern SEXP odesolve_jac_func;
 extern SEXP odesolve_envir;
 extern SEXP odesolve_gparms;
+extern SEXP odesolve_Y_names;
 
 /* odesolve_utils.c utilities */
 void init_N_Protect(void);
 void incr_N_Protect(void);
 void unprotect_all(void);
 void my_unprotect(int);
-void F77_NAME(rstop)(char *message);
-void F77_NAME(rwarn)(char *message);
 void Initodeparms(long int *, double *);
 
 /* Fortran "top-level" functions: */
